/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.db;

import java.util.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.util.*;

abstract class UserObjectOps extends OpsBase
{
  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected UserObjectOps(DBConnectionPool pool)
  {
    super(pool);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract operations
   *--------------------------------------------------------------------------------
   */

  abstract Object getProperty(int uid, PropertyKey key) throws DatabaseException;

  abstract Object setProperty(int uid, PropertyKey key, Object value) throws DatabaseException;

  abstract Object removeProperty(int uid, PropertyKey key) throws DatabaseException;

  abstract int[] getPropertyNamespaceIDs(int uid) throws DatabaseException;

  abstract Map getAllProperties(int uid, int namespace) throws DatabaseException;

  abstract void setLocked(int uid, boolean locked) throws DatabaseException;

  abstract void setNoSpam(int uid, boolean locked) throws DatabaseException;

  abstract void setEMailAddress(int uid, String addr) throws DatabaseException;

  abstract void setLastAccessed(int uid, java.util.Date date) throws DatabaseException;

  abstract String[] getAuthenticationData(int uid, int nsid, String method, String source_data)
      throws DatabaseException;

  abstract void putAuthenticationData(int uid, int nsid, String method, String source_data, String auth_data)
      throws DatabaseException;

  abstract void clearAuthenticationData(int uid, int nsid, String method, String source_data)
      throws DatabaseException;

} // end class UserObjectOps
