/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.dialog;

import org.apache.log4j.Logger;
import org.w3c.dom.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

class StdItemFactory implements DialogItemFactory
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Logger logger = Logger.getLogger(StdItemFactory.class);

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  StdItemFactory()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface DialogItemFactory
   *--------------------------------------------------------------------------------
   */

  public DialogItem createDialogItem(Element elt, DialogPLAF plaf) throws DialogException
  {
    String tagname = elt.getTagName();
    if (tagname.equals("button"))
      return new StdButton(elt,plaf);
    if (tagname.equals("checkbox"))
      return new CheckBoxField(elt);
    if (tagname.equals("countrylist"))
      return new CountryListField(elt);
    if (tagname.equals("dynamo-id"))
      return new DynamoIDField(elt);
    if (tagname.equals("email"))
      return new EmailAddressField(elt);
    if (tagname.equals("header"))
      return new HeaderItem(elt);
    if (tagname.equals("hidden"))
      return new HiddenField(elt);
    if (tagname.equals("int"))
      return new IntegerField(elt);
    if (tagname.equals("linktypelist"))
      return new LinkTypeField(elt);
    if (tagname.equals("localelist"))
      return new LocaleListField(elt);
    if (tagname.equals("password"))
      return new PasswordField(elt);
    if (tagname.equals("text"))
      return new TextField(elt);
    if (tagname.equals("textbox"))
      return new MultiLineTextField(elt);
    if (tagname.equals("tzlist"))
      return new TimeZoneListField(elt);
    
    throw new UnknownDialogFieldException(tagname,elt);

  } // end createDialogItem

} // end class StdItemFactory
