/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.dialog;

import java.util.*;
import org.w3c.dom.Element;
import com.silverwrist.util.*;
import com.silverwrist.dynamo.except.DialogException;

class TimeZoneListField extends PickListField
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final List TZ_LIST;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  TimeZoneListField(Element elt) throws DialogException
  {
    super(elt);

  } // end constructor

  protected TimeZoneListField(TimeZoneListField other)
  {
    super(other);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract implementations from class BaseDialogField
   *--------------------------------------------------------------------------------
   */

  public Object clone()
  {
    return new TimeZoneListField(this);

  } // end clone

  /*--------------------------------------------------------------------------------
   * Abstract implementations from class PickListField
   *--------------------------------------------------------------------------------
   */

  protected Iterator getChoices()
  {
    return TZ_LIST.iterator();

  } // end getChoices

  protected String getChoiceName(Object choice)
  {
    return ((TimeZone)choice).getID();

  } // end getChoiceName

  protected String getChoiceDisplay(Object choice)
  {
    TimeZone tz = (TimeZone)choice;
    return tz.getID() + " (" + tz.getDisplayName() + ")";

  } // end getChoiceDisplay

  protected Object getChoiceForName(String name)
  {
    return TimeZone.getTimeZone(name);

  } // end getChoiceForName

  protected boolean isValidChoice(Object choice)
  {
    return (choice instanceof TimeZone);

  } // end isValidChoice

  /*--------------------------------------------------------------------------------
   * Static initializer
   *--------------------------------------------------------------------------------
   */

  static
  { // get the list of IDs and sort them
    String ids[] = TimeZone.getAvailableIDs();
    Arrays.sort(ids);

    // now create the list of TimeZone objects
    ArrayList tmp = new ArrayList(ids.length);
    for (int i=0; i<ids.length; i++)
      tmp.add(TimeZone.getTimeZone(ids[i]));
    TZ_LIST = Collections.unmodifiableList(tmp);
    
  } // end static initializer

} // end class TimeZoneListField
