/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.event;

/**
 * An interface for signalling when a value is bound to or unbound from a
 * {@link com.silverwrist.dynamo.iface.SessionInfo SessionInfo} object.  If an object implementing this interface
 * is added to or removed from a <CODE>SessionInfo</CODE>, the methods on this interface are called to
 * reflect the lifecycle of the object.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface SessionValueBindListener extends DynamoEventListener
{
  /**
   * Called when this value is added to a {@link com.silverwrist.dynamo.iface.SessionInfo SessionInfo} object.
   *
   * @param event The event object for this event.  The
   *              {@link com.silverwrist.dynamo.event.SessionValueBindEvent#getValue() getValue()} method of
   *              this event returns this value.
   */
  public void valueAdded(SessionValueBindEvent event);

  /**
   * Called when this value is removed from a {@link com.silverwrist.dynamo.iface.SessionInfo SessionInfo} object.
   *
   * @param event The event object for this event.  The
   *              {@link com.silverwrist.dynamo.event.SessionValueBindEvent#getValue() getValue()} method of
   *              this event returns <CODE>null</CODE>.
   */
  public void valueRemoved(SessionValueBindEvent event);

  /**
   * Called when a new value is added to a {@link com.silverwrist.dynamo.iface.SessionInfo SessionInfo} object,
   * replacing this value.
   *
   * @param event The event object for this event.  The
   *              {@link com.silverwrist.dynamo.event.SessionValueBindEvent#getValue() getValue()} method of
   *              this event returns the value of the object that replaced this one.
   */
  public void valueReplaced(SessionValueBindEvent event);

} // end interface SessionValueBindListener
