/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.except;

import java.util.Locale;

/**
 * The root exception of all unchecked exceptions thrown by the Dynamo core code.  It is capable of
 * &quot;wrapping&quot; another exception within it.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public class DynamoRuntimeException extends RuntimeException
{
  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  /**
   * Constructs a new <CODE>DynamoRuntimeException</CODE>.
   */
  public DynamoRuntimeException()
  {
    super();

  } // end constructor

  /**
   * Constructs a new <CODE>DynamoRuntimeException</CODE> with a text message.
   *
   * @param msg The message to set in this exception.
   */
  public DynamoRuntimeException(String msg)
  {
    super(msg);

  } // end constructor

  /**
   * Constructs a new <CODE>DynamoRuntimeException</CODE> wrapping another exception.
   *
   * @param inner The exception wrapped by this one.
   */
  public DynamoRuntimeException(Throwable inner)
  {
    super(inner);

  } // end constructor

  /**
   * Constructs a new <CODE>DynamoRuntimeException</CODE> wrapping another exception.
   *
   * @param msg The message to set in this exception.
   * @param inner The exception wrapped by this one.
   */
  public DynamoRuntimeException(String msg, Throwable inner)
  {
    super(msg,inner);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  /**
   * Creates a localized description of this exception. Subclasses may override this method in
   * order to produce a locale-specific message. For subclasses that do not override this method,
   * the default implementation returns the same result as <CODE>getLocalizedMessage()</CODE>.
   *
   * @param locale The locale to render the message in.
   * @return The localized description of this exception.
   */
  public String getLocalizedMessage(Locale locale)
  {
    return getMessage();

  } // end getLocalizedMessage

} // end class DynamoRuntimeException
