/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.htmlcheck.tags;

import com.silverwrist.dynamo.HTMLTagSet;

public class HTMLTag
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_tagname;
  private boolean m_linebreak;
  private HTMLTagSet m_set;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  HTMLTag(String tagname, boolean linebreak, HTMLTagSet set)
  {
    m_tagname = tagname;
    m_linebreak = linebreak;
    m_set = set;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  public boolean equals(Object obj)
  {
    if (!(obj instanceof HTMLTag))
      return false;
    HTMLTag other = (HTMLTag)obj;
    return m_tagname.equals(other.m_tagname);

  } // end equals

  public int hashCode()
  {
    return m_tagname.hashCode();

  } // end hashCode

  public String toString()
  {
    return "<" + m_tagname + ">";

  } // end toString

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public String getTagName()
  {
    return m_tagname;

  } // end getTagName

  public boolean allowClose()
  {
    return false;

  } // end allowClose

  public boolean balanceTags()
  {
    return false;

  } // end balanceTags

  public boolean causeLineBreak(boolean is_closing)
  {
    return m_linebreak;

  } // end causeLineBreak

  public String makeClosingTag()
  {
    throw new RuntimeException("cannot make closing tags of basic HTMLTag");

  } // end makeClosingTag

  public HTMLTagSet getTagSet()
  {
    return m_set;

  } // end getTagSet

  public String rewrite(String tag_data, boolean is_closing, HTMLTagSite site)
  {
    return tag_data;

  } // end rewrite

} // end class HTMLTag
