/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

/**
 * A service interface which permits the retrieval of registered
 * {@link com.silverwrist.dynamo.iface.Authenticator Authenticator} objects.  Authenticators are identified by
 * namespace URI and name.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface AuthenticatorLookup
{
  /**
   * Retrieves an authenticator that has been registered with the system.
   *
   * @param method_namespace Namespace URI of the authenticator to be retrieved.
   * @param method Name of the authenticator to be retrieved.
   * @return The registered {@link com.silverwrist.dynamo.iface.Authenticator Authenticator}, or <CODE>null</CODE>
   *         if no such registered authenticator exists.
   */
  public Authenticator findAuthenticator(String method_namespace, String method);

} // end interface AuthenticatorLookup
