/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

import java.io.IOException;
import java.io.OutputStream;
import javax.servlet.http.HttpServletResponse;
import com.silverwrist.dynamo.except.RenderingException;

/**
 * The interface implemented by the rendering control object used with
 * {@link com.silverwrist.dynamo.iface.BinaryRenderer BinaryRenderer}.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface BinaryRenderControl extends RenderControl
{
  /**
   * Returns an {@link java.io.OutputStream OutputStream} which may be used to output the binary data of the rendering.
   *
   * @return The output stream.
   * @exception java.io.IOException If there was an I/O error getting the output stream.
   * @exception com.silverwrist.dynamo.except.RenderingException If there was another problem getting the output
   *            stream.
   */
  public OutputStream getStream() throws IOException, RenderingException;

} // end interface BinaryRenderControl
