/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

import java.security.Principal;
import com.silverwrist.dynamo.except.AuthenticationException;
import com.silverwrist.dynamo.except.DatabaseException;
import com.silverwrist.dynamo.except.DynamoSecurityException;

public interface DynamoUser extends Principal, NamedObject, SecureObjectStore
{
  public int getUID();

  public boolean isAnonymous();

  public boolean isLocked();

  public void setLocked(DynamoUser caller, boolean locked) throws DatabaseException, DynamoSecurityException;

  public boolean isNoSpam();

  public void setNoSpam(DynamoUser caller, boolean nospam) throws DatabaseException, DynamoSecurityException;

  public String getEMailAddress();

  public boolean setEMailAddress(DynamoUser caller, String addr)
      throws DatabaseException, DynamoSecurityException;

  public boolean authenticate(String method_namespace, String method, String source_data, String auth_data)
      throws DatabaseException, AuthenticationException;

  public void setAuthenticationData(DynamoUser caller, String method_namespace, String method,
				    String source_data, String auth_data)
      throws DatabaseException, AuthenticationException, DynamoSecurityException;

  public void clearAuthenticationData(DynamoUser caller, String method_namespace, String method,
				      String source_data) throws DatabaseException, DynamoSecurityException;

  public void clearAuthenticationData(DynamoUser caller, String method_namespace, String method)
      throws DatabaseException, DynamoSecurityException;

  public java.util.Date getCreationDate();

  public java.util.Date getLastAccessDate();

  public void setLastAccessDate(DynamoUser caller, java.util.Date date)
      throws DatabaseException, DynamoSecurityException;

} // end interface DynamoUser
