/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

/**
 * The interface which is used to configure the HTML Checker.  An instance of this interface is passed to all
 * registered {@link com.silverwrist.dynamo.iface.HTMLCheckerConfigurator HTMLCheckerConfigurator} objects, allowing
 * them to read off the configuration variables (as loaded from the database) and add active code to the HTML Checker
 * by means of this interface's methods.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface HTMLCheckerProfile extends ObjectProvider
{
  /**
   * Adds a new output filter which is called to process both non-markup data.  Markup data does not pass through
   * this filter.
   *
   * @param filter The output filter to add.
   */
  public void addOutputFilter(HTMLOutputFilter filter);

  /**
   * Adds a new output filter which is called to process both markup and non-markup data.
   *
   * @param filter The output filter to add.
   */
  public void addRawOutputFilter(HTMLOutputFilter filter);

  /**
   * Adds a new rewriter which can rewrite text strings in the input.  A "string" is a series of non-whitespace
   * characters delimited by whitespace.
   *
   * @param rewriter The rewriter to add.
   */
  public void addStringRewriter(HTMLRewriter rewriter);

  /**
   * Adds a new rewriter which can rewrite text words in the input.  A "word" is a series of word characters (letters,
   * apostrophe, hyphen) delimited by non-word characters or whitespace.
   *
   * @param rewriter The rewriter to add.
   */
  public void addWordRewriter(HTMLRewriter rewriter);

  /**
   * Adds a new rewriter which can rewrite text contained within angle brackets in the HTML Checker input.
   *
   * @param rewriter The rewriter to add.
   */
  public void addTagRewriter(HTMLRewriter rewriter);

  /**
   * Adds a new rewriter which can rewrite text contained within parentheses in the HTML Checker input.
   *
   * @param rewriter The rewriter to add.
   */
  public void addParenRewriter(HTMLRewriter rewriter);

  /**
   * Adds a new rewriter which can rewrite text contained within square brackets in the HTML Checker input.
   *
   * @param rewriter The rewriter to add.
   */
  public void addBracketRewriter(HTMLRewriter rewriter);

  /**
   * Adds a new rewriter which can rewrite text contained within curly braces in the HTML Checker input.
   *
   * @param rewriter The rewriter to add.
   */
  public void addBraceRewriter(HTMLRewriter rewriter);

} // end interface HTMLCheckerProfile
