/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

/**
 * An interface implemented by Dynamo output objects that wish to override some or all of the normal processing
 * for output.  If an output object implements this interface, its {@link #getRenderFlags()} method is called
 * to get the flags for the result; if not, the value of {@link #DEFAULT DEFAULT} is used for the rendering flags.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface RenderFlags
{
  /**
   * Indicates that this object would like to refrain from adding any cookies to the output.
   */
  public static final long NO_COOKIE_FLUSH = 0x01;

  /**
   * Indicates that this object would like to refrain from adding any extra HTTP headers to the output.
   */
  public static final long NO_HEADER_FLUSH = 0x02;

  /**
   * Indicates that this object would like to refrain from flushing the response after rendering the
   * object.
   */
  public static final long NO_RESPONSE_FLUSH = 0x04;

  /**
   * The default render flags used by objects that do not implement this interface.
   */
  public static final long DEFAULT = 0;

  /**
   * Returns the rendering flags to be used by this object.
   *
   * @return The rendering flags to be used by this object.
   */
  public long getRenderFlags();

} // end interface RenderFlags
