/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

import java.io.IOException;
import java.io.PrintWriter;
import com.silverwrist.dynamo.except.RenderingException;

/**
 * The interface implemented by the rendering control object used with
 * {@link com.silverwrist.dynamo.iface.TextRenderer TextRenderer}.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface TextRenderControl extends RenderControl
{
  /**
   * Returns a {@link java.io.PrintWriter PrintWriter} which may be used to output the textual data of the rendering.
   *
   * @return The output writer.
   * @exception java.io.IOException If there was an I/O error getting the output writer.
   * @exception com.silverwrist.dynamo.except.RenderingException If there was another problem getting the output
   *            writer.
   */
  public PrintWriter getWriter() throws IOException, RenderingException;

  /**
   * Renders another object to the output at the output's current position.  The object to be rendered must be
   * renderable in text format, either by means of a registered
   * {@link com.silverwrist.dynamo.iface.TextRenderer TextRenderer} object, by means of implementing
   * {@link com.silverwrist.dynamo.iface.SelfRenderable SelfRenderable} (which implementation cannot use the
   * binary or special rendering methods of {@link com.silverwrist.dynamo.iface.SelfRenderControl SelfRenderControl}),
   * or by default (via the object's {@link java.lang.Object#toString() toString()} method).
   *
   * @param obj The subobject to be rendered.
   * @exception java.io.IOException If there was an I/O error rendering the object.
   * @exception com.silverwrist.dynamo.except.RenderingException If there was another problem rendering the object.
   */
  public void renderSubObject(Object obj) throws IOException, RenderingException;

} // end interface TextRenderControl
