/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.servlet;

import com.silverwrist.dynamo.HttpStatusCode;
import com.silverwrist.dynamo.Namespaces;
import com.silverwrist.dynamo.db.ImageStore;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

public class ImageServlet extends ServletBase
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private ImageStore m_imagestore;   // pointer to the image store

  /*--------------------------------------------------------------------------------
   * Abstract implementations from class ServletBase
   *--------------------------------------------------------------------------------
   */

  protected Object process(Request r, Application app) throws Exception
  {
    try
    { // parse the image ID, get the data, and return it
      int imgid = Integer.parseInt(r.getExtraPath().substring(1));
      DataItem item = m_imagestore.getImage(imgid);
      if (item==null)
	return new HttpErrorMessage(HttpStatusCode.E_NOTFOUND);
      else
	return item;

    } // end try
    catch (NumberFormatException nfe)
    { // invalid image URL
      return new HttpErrorMessage(HttpStatusCode.E_BAD_REQUEST);

    } // end catch
    catch (DatabaseException de)
    { // unable to get the image from the database
      return new HttpErrorMessage(HttpStatusCode.E_INTERNAL,de);

    } // end catch

  } // end process

  /*--------------------------------------------------------------------------------
   * Overrides from class ServletBase
   *--------------------------------------------------------------------------------
   */

  protected void initServlet(ServiceProvider services) throws DynamoException
  {
    // Get the name of the image store.
    ObjectProvider oprov = (ObjectProvider)(services.queryService(ObjectProvider.class));
    String store_name = (String)(oprov.getObject(Namespaces.SERVLET_INIT_NAMESPACE,"image.store"));

    // Get the subsystem object.
    m_imagestore = (ImageStore)(GetObjectUtils.getDynamoComponent(services,ImageStore.class,store_name));

  } // end initServlet

} // end class ImageServlet
