/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.util;

import java.io.IOException;
import java.io.PrintWriter;
import com.silverwrist.dynamo.except.RenderingException;
import com.silverwrist.dynamo.iface.TextRenderControl;

public class FilterTextRenderControl implements TextRenderControl
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private TextRenderControl m_inner;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public FilterTextRenderControl(TextRenderControl inner)
  {
    m_inner = inner;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface ServiceProvider
   *--------------------------------------------------------------------------------
   */

  /**
   * Queries this object for a specified service.
   *
   * @param klass The class of the object that should be returned as a service.
   * @return A service object.  The service object is guaranteed to be of the class
   *         specified by <CODE>klass</CODE>; that is, if <CODE>queryService(klass)</CODE>
   *         yields some object <CODE>x</CODE>, then the expression <CODE>klass.isInstance(x)</CODE>
   *         is true.
   * @exception com.silverwrist.dynamo.except.NoSuchServiceException If no service is available in
   *            the specified class.
   */
  public Object queryService(Class klass)
  {
    return m_inner.queryService(klass);

  } // end queryService

  /**
   * Queries this object for a specified service.
   *
   * @param klass The class of the object that should be returned as a service.
   * @param serviceid ID for the service to be requested, to further discriminate between requests.
   * @return A service object.  The service object is guaranteed to be of the class
   *         specified by <CODE>klass</CODE>; that is, if <CODE>queryService(klass)</CODE>
   *         yields some object <CODE>x</CODE>, then the expression <CODE>klass.isInstance(x)</CODE>
   *         is true.
   * @exception com.silverwrist.dynamo.except.NoSuchServiceException If no service is available in
   *            the specified class.
   */
  public Object queryService(Class klass, String serviceid)
  {
    return m_inner.queryService(klass,serviceid);

  } // end queryService

  /*--------------------------------------------------------------------------------
   * Implementations from interface RenderControl
   *--------------------------------------------------------------------------------
   */

  public void setContentType(String type) throws RenderingException
  {
    m_inner.setContentType(type);

  } // end setContentType

  public void setContentLength(int length) throws RenderingException
  {
    m_inner.setContentLength(length);

  } // end setContentLength

  /*--------------------------------------------------------------------------------
   * Implementations from interface TextRenderControl
   *--------------------------------------------------------------------------------
   */

  public PrintWriter getWriter() throws IOException, RenderingException
  {
    return m_inner.getWriter();

  } // end getWriter

  public void renderSubObject(Object obj) throws IOException, RenderingException
  {
    m_inner.renderSubObject(obj);

  } // end renderSubObject

} // end class FilterTextRenderControl
