/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.xmlrpc;

import java.util.regex.*;
import com.silverwrist.dynamo.except.*;

class RegisteredDispatcher
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private Pattern m_pattern;
  private String m_expr;
  private XmlRpcDispatcher m_dispatcher;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  RegisteredDispatcher(String expr, XmlRpcDispatcher dispatcher) throws ConfigException
  {
    try
    { // compile the pattern and save the dispatcher
      if (!(expr.startsWith("^")))
	expr = "^" + expr;
      m_pattern = Pattern.compile(expr);
      m_expr = expr;
      m_dispatcher = dispatcher;

    } // end try
    catch (PatternSyntaxException e)
    { // convert this to a ConfigException
      ConfigException ce = new ConfigException(RegisteredDispatcher.class,"XmlRpcMessages","pattern.error",e);
      ce.setParameter(0,expr);
      throw ce;
      
    } // end catch

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  public boolean equals(Object o)
  {
    if ((o==null) || !(o instanceof RegisteredDispatcher))
      return false;
    RegisteredDispatcher other = (RegisteredDispatcher)o;
    return (m_expr.equals(other.m_expr) && (m_dispatcher==other.m_dispatcher));

  } // end equals

  public int hashCode()
  {
    return m_expr.hashCode() ^ System.identityHashCode(m_dispatcher);

  } // end hashCode

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  boolean match(String method_name)
  {
    return m_pattern.matcher(method_name).matches();

  } // end match
  
  XmlRpcDispatcher getDispatcher()
  {
    return m_dispatcher;

  } // end getDispatcher

} // end class RegisteredDispatcher
