/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.frame;

/**
 * An interface implemented by content objects that are to be rendered inside the Venice frame.
 * The Venice frame provides the outer border, top bar with basic links and ad banner, left bar with
 * menus, and page footer with standard text and graphics.
 * <P>Objects implementing this interface are intercepted by an
 * {@link com.silverwrist.dynamo.iface.OutputObjectFilter OutputObjectFilter} installed by the
 * {@link com.silverwrist.venice.frame.FrameAssembler FrameAssembler} class, and are wrapped in an object
 * ({@link com.silverwrist.venice.frame.FrameRendering FrameRendering}), which then renders it as part
 * of its rendering process.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface FramedContent
{
  /**
   * Returns the desired menu selector for this page.  The <EM>menu selector</EM> is a string that specifies
   * which menu is to be displayed on the left menu bar, in addition to the "global menu."  This value may
   * be <CODE>null</CODE>, in which case the current menu selector is not changed.
   *
   * @return The desired menu selector.
   */
  public String getMenuSelector();

  /**
   * Returns the desired title for the page.  This title is concatenated with the <EM>site title</EM> (set in
   * global properties) to form the actual page title that gets sent to the browser.
   *
   * @return The desired page title.
   */
  public String getPageTitle();

  /**
   * Returns the desired quick ID for the page.  The <EM>page quick ID</EM> is a small text string which can be used
   * to "tag" the page with a unique identifier, for use with external tools such as offsite hit counters.
   * If this value is <CODE>null</CODE>, the quick ID is not used for this page.
   *
   * @return The desired page quick ID.
   */
  public String getPageQID();

} // end interface FramedContent
