/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.menu;

import com.silverwrist.dynamo.db.NamespaceCache;
import com.silverwrist.dynamo.db.OpsBase;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

abstract class MenuDatabaseOps extends OpsBase
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private NamespaceCache m_ns_cache;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected MenuDatabaseOps(DBConnectionPool pool)
  {
    super(pool);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Internal operations
   *--------------------------------------------------------------------------------
   */

  protected final int namespaceNameToId(String name) throws DatabaseException
  {
    return m_ns_cache.namespaceNameToId(name);

  } // end namespaceNameToId

  protected final String namespaceIdToName(int id) throws DatabaseException
  {
    return m_ns_cache.namespaceIdToName(id);

  } // end namespaceIdToName

  /*--------------------------------------------------------------------------------
   * Abstract operations
   *--------------------------------------------------------------------------------
   */

  abstract MenuDefinition getMenu(String namespace, String name) throws DatabaseException;

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  void setNamespaceCache(NamespaceCache nsc)
  {
    m_ns_cache = nsc;

  } // end setNamespaceCache

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  static MenuDatabaseOps get(DBConnectionPool pool) throws ConfigException
  {
    return (MenuDatabaseOps)get(pool,MenuDatabaseOps.class.getClassLoader(),
				MenuDatabaseOps.class.getName() + "_","MenuDatabaseOps");

  } // end get

} // end class MenuDatabaseOps
