/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.sourceid;

import org.sourceid.sso.handlers.AccountHandler;
import org.sourceid.sso.util.*;
import org.sourceid.sso.xml.*;
import org.sourceid.sso.xml.lib.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

public abstract class LibrarySourceID
{
  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected LibrarySourceID()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public IDPDescriptorType castIDPDescriptorType(Object o)
  {
    if (o instanceof IDPDescriptorType)
      return (IDPDescriptorType)o;
    throw new ClassCastException("LibrarySourceID.castIDPDescriptorType: invalid cast");

  } // end castIDPDescriptorType

  public ProviderDirectory getProviderDirectory(Request r)
  {
    ExternalAppAttributes eaa = (ExternalAppAttributes)(r.queryService(ExternalAppAttributes.class));
    return (ProviderDirectory)(eaa.getAttribute("org.sourceid.sso.providerDirectory"));
    
  } // end getProviderDirectory

  public SPSession getSessionInfoForProvider(Request r, String providerID)
  {
    ExternalSessionAttributes esa = (ExternalSessionAttributes)(r.queryService(ExternalSessionAttributes.class));
    return (SPSession)(esa.getAttribute("org.sourceid.sso.session." + providerID));

  } // end getSessionInfoForProvider

  public AccountHandler getAccountHandler(Request r)
  {
    ExternalAppAttributes eaa = (ExternalAppAttributes)(r.queryService(ExternalAppAttributes.class));
    return (AccountHandler)(eaa.getAttribute("org.sourceid.sso.accountHandler"));

  } // end getAccountHandler

  /*--------------------------------------------------------------------------------
   * Abstract operations which must be overridden
   *--------------------------------------------------------------------------------
   */

  public abstract boolean isUserFederatedWith(Request r, String providerID) throws DatabaseException;

} // end class LibrarySourceID
